#
# spec file for package lonote
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lonote
Version:        3.2.13
Release:        6.3
Summary:        A personal note-taking application
License:        GPL-3.0 AND Apache-2.0
Group:          Productivity/Office/Organizers
Url:            https://bitbucket.org/civalin/lonote
Source0:        https://bitbucket.org/civalin/lonote/get/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
Requires:       python3-dbm
Requires:       python3-xml
BuildArch:      noarch

%description
Lonote is a personal note-taking application based on python3
and modern browsers.
It features in well interact UI, minimal design, structural notes,
auto reloading, archiving and versioning.

%prep
%setup -q -c -T
tar xzf %{SOURCE0} --strip-components=1

sed -i "s|#!/usr/bin/python3||" lonotelib/diff_match_patch.py # Fix non-executable script
sed -i '/^#!\/usr\/bin\/env/d' lonotelib/bottle.py
chmod -x server/static/diff-match-patch/diff_match_patch.js \
         server/static/glyphicons/fonts/glyphiconshalflings-regular.svg

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
# Remove wrongly installed docs
rm -rf %{buildroot}%{_datadir}/doc/%{name}/
# Fix Categories in desktop file
sed -i "s/Development;//" %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file %{name} Office ProjectManagement
# Fix locale
find %{buildroot}%{_datadir}/locale -type f -name "*.po" -delete
%find_lang %{name}
# Fix pixmaps
rm -rf %{buildroot}%{_datadir}/pixmaps/%{name}.ico
# Hidden file for dir
find %{buildroot} -type f -name "*.swp" -delete
find %{buildroot} -type f -name ".DS_Store" -delete
find %{buildroot} -type f -name ".hgempty" -delete

%fdupes %{buildroot}

%files -f %{name}.lang
%defattr(-,root,root)
%doc README.rst doc/{Apache_License,CHANGELOG.rst,LICENSE.rst}
%{_bindir}/lonote
%{python3_sitelib}/*
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/lonote.*
%{_datadir}/%{name}/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/pixmaps/%{name}.png

%changelog
* Wed Feb 21 2018 aloisio@gmx.com
- Update to version 3.2.13
  * Fixed: hotkey ``a`` malfunction in bookshelf modal.
  * Fixed: hotkey ``a``, ``q``, ``z`` in bookshelf menu also send
    the character to the editor.
  version 3.2.12
  * Fixed: Cannot convert ``.lobook`` files in python 3.4.
  * Enhanced: Minor enhance tab navigation.
  version 3.2.11
  * Updated & Fix: ``bottlepy`` 0.12.5 -> 0.12.7. Fix python 3.4
    book upload error.
  * Updated: ``whoosh`` 2.5.5 -> 2.5.7, ``mako`` 0.8.1 -> 1.0.0,
    ``bootstrap`` 3.1.1 -> 3.2.0
  version 3.2.10
  * Fixed: Change "#" in resource file name are not allow.
  * Fixed: Using LoNote between python 3.3 and python 3.4 platform
    will not crash by indexing anymore.
  * Fixed: Delete some section which sid are non-ascii may cause
    encode problem (in window platform).
  version 3.2.9
  * Changed: Rewrite ``lonote.less`` -> ``lonote.scss`` by sass_\ .
  * Changed: Minor improve the search hint trigger.
  * Enhanced: Add some buttons in "search hint popover" for quick
    insert search tags.
  * Fixed: Increase waiting time for browser starting trigger from
    20sec to 2min.
  * New: Add appdata file for the `new freedesktop standard`_ .
  version 3.2.8
  * **HOT FIX:** Deal the memory cache un-sync problem.
  * Changed: Auto focus to search bar when search dialog be shown.
  * Changed: Rewrite ``lonote.css`` by lesscss_ & make
    ``lonote.css`` can work with most bootstrap theme.
  * Enhanced: Auto update the search index when LoNote started.
  * Enhanced: Add a button for update the index manually.
  * Enhanced: Add a ``custom.css`` file for global style configure.
  * Updated: bootstrap 3.1.0 -> 3.1.1
- New URL
- Drop Qt dependencies as the interface is purely HTML5 now
* Mon Apr 28 2014 i@marguerite.su
- update version 3.2.7
  * Fixed: Minor UI fixed.
  * Enhanced: Search results split into multiple pages.
  * Enhanced: Implement page compress, trim whitespace,
    AJAX cache technique to reduce the data transfer
    about 80 ~ 90%%. Especially if you have a big bookshelf.
  * Enhanced: Image Resources can be viewed by lightbox now.
  * Changed: Redirect to ``bookshelf.html`` after user upload
    some books.
* Mon Oct 22 2012 i@marguerite.su
- Update to 1.8.7
  * fix: xdg warning now fixed. (issue 19)
  * fix: delete iframe object on page navgation.
    to avoid youtube object remains on screen after page nav. (issue 12)
* Sat Sep  8 2012 i@marguerite.su
- Update to 1.8.6
  * fix: crash when deleting page in 1.8.5
  * fix: non-sync loading crash in openSUSE in 1.8.5
* Fri May  4 2012 i@marguerite.su
- Update to version 1.7.9
  * contacting author for changelog.
* Tue Mar  6 2012 saschpe@suse.de
- Update to version 1.5.10
- Spec file cleanup:
  * Avoid source services
  * Simpler doc installation
  * Ran spec-cleaner
* Tue Feb 28 2012 i@marguerite.su
- disabled _service. next submit to Factory.
* Thu Feb  9 2012 i@marguerite.su
- initial package 1.0
